@@ -37,7 +37,8 @@ public class Constants
 		"Sharad Shankar (http://www.logicbrick.com)\n" + Catalog.GetString("OpenCV Detection of knee angle."), 
 		"Onkar Nath Mishra (http://www.logicbrick.com)\n" + Catalog.GetString("OpenCV Detection of knee angle."),
 		"Andoni Morales Alastruey (http://ylatuya.es)\n" + Catalog.GetString("Installation support: Autotools, packaging, bundle."), 
-		"Carlos J. Gil Bellosta (http://www.datanalytics.com)\n" + Catalog.GetString("Statistics support.") 
+		"Carlos J. Gil Bellosta (http://www.datanalytics.com)\n" + Catalog.GetString("Statistics support."),
+		"Teng Wei Hua (wadedang@gmail.com)\n" + Catalog.GetString("Translation of Firmware to C, and new firmware features.") 
 	};
 	public static string [] Documenters = {
 		"Xavier de Blas Foix (xaviblas@gmail.com)\n\n",
