@@ -15,12 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 using System.Data;
 using System.Text; //StringBuilder
+using Gtk;
 
 using System.Threading;
 using System.IO.Ports;
@@ -57,23 +58,29 @@ public class EventExecute
 	}
 	protected eventType needUpdateGraphType;
 	
-	protected string syncMessage;
-	protected bool needShowSyncMessage;
+	//protected string syncMessage;
+	//protected bool needShowSyncMessage;
+	protected string feedbackMessage;
+	protected bool needShowFeedbackMessage;
 
 	//instances with the info to create
-	protected PrepareEventGraphJumpSimple prepareEventGraphJumpSimple; 
-	protected PrepareEventGraphJumpReactive prepareEventGraphJumpReactive;
-	protected PrepareEventGraphRunSimple prepareEventGraphRunSimple;
-	protected PrepareEventGraphRunInterval prepareEventGraphRunInterval;
-	protected PrepareEventGraphPulse prepareEventGraphPulse;
-	protected PrepareEventGraphReactionTime prepareEventGraphReactionTime;
-	protected PrepareEventGraphMultiChronopic prepareEventGraphMultiChronopic;
+	public PrepareEventGraphJumpSimple PrepareEventGraphJumpSimpleObject; 
+	public PrepareEventGraphJumpReactive PrepareEventGraphJumpReactiveObject;
+	public PrepareEventGraphRunSimple PrepareEventGraphRunSimpleObject;
+	public PrepareEventGraphRunInterval PrepareEventGraphRunIntervalObject;
+	public PrepareEventGraphPulse PrepareEventGraphPulseObject;
+	public PrepareEventGraphReactionTime PrepareEventGraphReactionTimeObject;
+	public PrepareEventGraphMultiChronopic PrepareEventGraphMultiChronopicObject;
 	
 	protected bool needEndEvent;
 	
 	protected bool volumeOn;
+	protected double progressbarLimit;
 	protected RepetitiveConditionsWindow repetitiveConditionsWin;
 
+	protected ExecutingGraphData egd;
+	
+
 
 	//better as private and don't inherit, don't know why
 	//protected Chronopic cp;
@@ -100,14 +107,16 @@ public class EventExecute
 	
 	protected States loggedState;		//log of last state
 	//protected Gtk.ProgressBar progressBar;
-	protected Gtk.Statusbar appbar;
+	protected Gtk.TextView event_execute_textview_message;
 	protected Gtk.Window app;
 	protected int pDN;
 	
 	protected int timesForSavingRepetitive; //number of times that this repetive event needs for being recorded in temporal table
 
 	//for raise a signal and manage it on chronojump.cs
+	protected Gtk.Button fakeButtonUpdateGraph;
 	protected Gtk.Button fakeButtonFinished;
+	protected Gtk.Button fakeButtonEventEnded;
 	
 	//for cancelling from chronojump.cs
 	protected bool cancel;
@@ -137,7 +146,8 @@ public class EventExecute
 	
 
 
-	protected EventExecuteWindow eventExecuteWin;
+	//protected EventExecuteWindow eventExecuteWin;
+	//protected ChronoJumpWindow app1;
 	
 	protected Event eventDone;
 	
@@ -255,10 +265,13 @@ public class EventExecute
 
 		//updateTimeProgressBar();
 		if(needEndEvent) {
-			eventExecuteWin.EventEnded();
+			//app1.EventEnded();
+			fakeButtonEventEnded.Click();
 			//needEndEvent = false;
 			if(needUpdateGraphType == eventType.MULTICHRONOPIC && type == Constants.RunAnalysisName && finish) 
-				eventExecuteWin.RunATouchPlatform();
+				//app1.RunATouchPlatform();
+				//fakeButtonRunATouchPlatform.Click();
+				runATouchPlatform();
 		} else 
 			updateTimeProgressBar();
 		
@@ -269,7 +282,8 @@ public class EventExecute
 
 		if(needUpdateEventProgressBar) {
 			//update event progressbar
-			eventExecuteWin.ProgressBarEventOrTimePreExecution(
+			//app1.ProgressBarEventOrTimePreExecution(
+			progressBarEventOrTimePreExecution(
 					updateProgressBar.IsEvent,
 					updateProgressBar.PercentageMode,
 					updateProgressBar.ValueToShow
@@ -278,9 +292,7 @@ public class EventExecute
 			needUpdateEventProgressBar = false;
 		}
 		
-//	Console.WriteLine("pulse update graph");	
 		if(needUpdateGraph) {
-//	Console.WriteLine("pulse update graph 2");	
 			//solve problems when runAnalysis ended and tries to paint window
 			if(needUpdateGraphType == eventType.MULTICHRONOPIC && type == Constants.RunAnalysisName && finish) 
 				Console.WriteLine("is MC, RA, finished!");	
@@ -290,19 +302,18 @@ public class EventExecute
 			} else
 				updateGraph();
 	
-//			Console.WriteLine("pulse update graph 3");	
 			needUpdateGraph = false;
 		}
-//	Console.WriteLine("pulse update graph 4");	
 		
 		if(needSensitiveButtonFinish) {
-			eventExecuteWin.ButtonFinishMakeSensitive();
+			//ButtonFinishMakeSensitive();
+			egd.Button_finish.Sensitive = true;
 			needSensitiveButtonFinish = false;
 		}
 		
-		if(needShowSyncMessage) {
-			eventExecuteWin.ShowSyncMessage(syncMessage);
-			needShowSyncMessage = false;
+		if(needShowFeedbackMessage) {
+			egd.Textview_message.Buffer = UtilGtk.TextViewPrint(feedbackMessage);
+			needShowFeedbackMessage = false;
 		}
 		
 		
@@ -311,9 +322,59 @@ public class EventExecute
 			finish = true;
 			updateProgressBarForFinish();
 		} 
-//	Console.WriteLine("pulse done");	
-		//else 
-		//	updateTimeProgressBar();
+	}
+	
+	private void runATouchPlatform() {
+		string message = Catalog.GetString("Always remember to touch platform at ending. If you don't do it, Chronojump will crash at next execution.");
+		egd.Textview_message.Buffer = UtilGtk.TextViewPrint(message);
+	}
+
+	public void RunANoStrides() {
+		string message = Catalog.GetString("This Run Analysis is not valid because there are no strides.");
+		egd.Textview_message.Buffer = UtilGtk.TextViewPrint(message);
+	}
+	
+	protected void progressBarEventOrTimePreExecution (bool isEvent, bool percentageMode, double events) 
+	{
+		if (isEvent) 
+			progressbarEventOrTimeExecution (egd.Progressbar_event, percentageMode, egd.Label_event_value, events);
+		else
+			progressbarEventOrTimeExecution (egd.Progressbar_time, percentageMode, egd.Label_time_value, events);
+	}
+
+	protected void progressbarEventOrTimeExecution (Gtk.ProgressBar progressbar, bool percentageMode, Gtk.Label label_value, double events)
+	{
+		if(progressbarLimit == -1) {	//unlimited event (until 'finish' is clicked)
+			progressbar.Pulse();
+			//label_value.Text = events.ToString();
+			if(events != -1)
+				label_value.Text = Math.Round(events,3).ToString();
+		} else {
+			if(percentageMode) {
+				double myFraction = events / progressbarLimit *1.0;
+
+				if(myFraction > 1)
+					myFraction = 1;
+				else if(myFraction < 0)
+					myFraction = 0;
+
+				progressbar.Fraction = myFraction;
+				//progressbar.Text = Util.TrimDecimals(events.ToString(), 1) + " / " + progressbarLimit.ToString();
+				if(events == -1) //we don't want to display nothing
+					//progressbar.Text = "";
+					label_value.Text = "";
+				else 
+					label_value.Text = Math.Round(events,3).ToString();
+			} else {
+				//activity mode
+				progressbar.Pulse();
+
+				//pass -1 in events in activity mode if don't want to use this label
+				if(events != -1)
+					//label_value.Text = Util.TrimDecimals(events.ToString(), 1);
+					label_value.Text = Math.Round(events,3).ToString();
+			}
+		}
 	}
 			
 	//check if we should simulate an arriving or leaving the platform depending on random time values
@@ -331,7 +392,6 @@ public class EventExecute
 		
 		//if the time is too much, finish
 		if(timerCount - simulatedTimeAccumulatedBefore > timeMax) {
-//				Log.WriteLine("EXCEEDES MAX!");
 				simulateChangePlatform();
 		}
 		
@@ -342,10 +402,8 @@ public class EventExecute
 			//rand.NextDouble gives a value between 0 and 1
 			//if we multiply by the (simulatedRange * 10 +1), then we will have 4 options if the range is ,4
 			//check if the value is less than 1 (it's one change in four options) and if it's 1, then simulated the change platform
-			//double dice = 0;
 			double myRand = rand.NextDouble();
 			double dice = myRand * (simulatedRange *10 +1);
-//			Log.WriteLine(string.Format("rand: {0}, dice: {1}", myRand, dice));
 			if (dice < 1)
 			{
 				simulateChangePlatform();
@@ -374,79 +432,18 @@ public class EventExecute
 	}
 			
 	private void updateGraph() {
-		switch(needUpdateGraphType) {
-			case eventType.JUMP:
-				Log.Write("update graph: JUMP");
-				eventExecuteWin.PrepareJumpSimpleGraph(
-						prepareEventGraphJumpSimple.tv, 
-						prepareEventGraphJumpSimple.tc);
-				break;
-			case eventType.JUMPREACTIVE:
-				Log.Write("update graph: JUMPREACTIVE");
-				eventExecuteWin.PrepareJumpReactiveGraph(
-						prepareEventGraphJumpReactive.lastTv, 
-						prepareEventGraphJumpReactive.lastTc,
-						prepareEventGraphJumpReactive.tvString,
-						prepareEventGraphJumpReactive.tcString,
-						volumeOn, repetitiveConditionsWin);
-				break;
-			case eventType.RUN:
-				Log.Write("update graph: RUN");
-				eventExecuteWin.PrepareRunSimpleGraph(
-						prepareEventGraphRunSimple.time, 
-						prepareEventGraphRunSimple.speed);
-				break;
-			case eventType.RUNINTERVAL:
-				Log.Write("update graph: RUNINTERVAL");
-				eventExecuteWin.PrepareRunIntervalGraph(
-						prepareEventGraphRunInterval.distance, 
-						prepareEventGraphRunInterval.lastTime,
-						prepareEventGraphRunInterval.timesString,
-						prepareEventGraphRunInterval.distanceTotal,
-						prepareEventGraphRunInterval.distancesString,
-						volumeOn, repetitiveConditionsWin);
-				break;
-			case eventType.PULSE:
-				Log.Write("update graph: PULSE");
-				eventExecuteWin.PreparePulseGraph(
-						prepareEventGraphPulse.lastTime, 
-						prepareEventGraphPulse.timesString);
-				break;
-			case eventType.REACTIONTIME:
-				Log.Write("update graph: REACTIONTIME");
-				eventExecuteWin.PrepareReactionTimeGraph(
-						prepareEventGraphReactionTime.time); 
-				break;
-			case eventType.MULTICHRONOPIC:
-				Log.Write("update graph: MULTICHRONOPIC");
-				eventExecuteWin.PrepareMultiChronopicGraph(
-						//prepareEventGraphMultiChronopic.timestamp, 
-						prepareEventGraphMultiChronopic.cp1StartedIn, 
-						prepareEventGraphMultiChronopic.cp2StartedIn, 
-						prepareEventGraphMultiChronopic.cp3StartedIn, 
-						prepareEventGraphMultiChronopic.cp4StartedIn, 
-						prepareEventGraphMultiChronopic.cp1InStr, 
-						prepareEventGraphMultiChronopic.cp1OutStr,
-						prepareEventGraphMultiChronopic.cp2InStr, 
-						prepareEventGraphMultiChronopic.cp2OutStr,
-						prepareEventGraphMultiChronopic.cp3InStr, 
-						prepareEventGraphMultiChronopic.cp3OutStr,
-						prepareEventGraphMultiChronopic.cp4InStr, 
-						prepareEventGraphMultiChronopic.cp4OutStr
-						);
-				break;
-		}
+		fakeButtonUpdateGraph.Click();
 	}
 	
 	protected virtual bool shouldFinishByTime() {
 		return true;
 	}
 
-	//called by the GTK loop (can call eventExecuteWin directly
+	//called by the GTK loop (can call app1 directly
 	protected virtual void updateProgressBarForFinish() {
 	}
 	
-	//called by the GTK loop (can call eventExecuteWin directly
+	//called by the GTK loop (can call app1 directly
 	protected virtual void updateTimeProgressBar() {
 	}
 	
@@ -467,7 +464,8 @@ public class EventExecute
 	{
 		cancel = true;
 		totallyCancelled = true;
-		eventExecuteWin.EventEnded();
+		//app1.EventEnded();
+		fakeButtonEventEnded.Click();
 		
 		//event will be raised, and managed in chronojump.cs
 		fakeButtonFinished.Click();
@@ -490,13 +488,22 @@ public class EventExecute
 		Console.WriteLine("at event.cs");
 	}
 			
-	public Gtk.Button FakeButtonFinished
-	{
-		get {
-			return	fakeButtonFinished;
-		}
+	public Gtk.Button FakeButtonUpdateGraph {
+		get { return fakeButtonUpdateGraph; }
 	}
 
+	public Gtk.Button FakeButtonFinished {
+		get { return fakeButtonFinished; }
+	}
+
+	public Gtk.Button FakeButtonEventEnded {
+		get { return fakeButtonEventEnded; }
+	}
+
+	//public Gtk.Button FakeButtonRunATouchPlatform {
+	//	get { return fakeButtonRunATouchPlatform; }
+	//}
+
 	//called from chronojump.cs for finishing events earlier
 	public bool Finish
 	{
