@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -48,10 +48,11 @@ public class JumpExecute : EventExecute
 	}
 
 	//jump execution
-	public JumpExecute(EventExecuteWindow eventExecuteWin, int personID, string personName, int sessionID, string type, double fall, double weight,  
-			Chronopic cp, Gtk.Statusbar appbar, Gtk.Window app, int pDN, bool volumeOn)
+	public JumpExecute(int personID, string personName, int sessionID, string type, double fall, double weight,  
+			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool volumeOn,
+			double progressbarLimit, ExecutingGraphData egd 
+			)
 	{
-		this.eventExecuteWin = eventExecuteWin;
 		this.personID = personID;
 		this.personName = personName;
 		this.sessionID = sessionID;
@@ -60,11 +61,13 @@ public class JumpExecute : EventExecute
 		this.weight = weight;
 		
 		this.cp = cp;
-		this.appbar = appbar;
+		this.event_execute_textview_message = event_execute_textview_message;
 		this.app = app;
 
 		this.pDN = pDN;
 		this.volumeOn = volumeOn;
+		this.progressbarLimit = progressbarLimit;
+		this.egd = egd;
 	
 		if(TypeHasFall) {
 			hasFall = true;
@@ -72,6 +75,8 @@ public class JumpExecute : EventExecute
 			hasFall = false;
 		}
 		
+		fakeButtonUpdateGraph = new Gtk.Button();
+		fakeButtonEventEnded = new Gtk.Button();
 		fakeButtonFinished = new Gtk.Button();
 		
 		simulated = false;
@@ -120,7 +125,8 @@ public class JumpExecute : EventExecute
 		
 		
 		if (platformState==Chronopic.Plataforma.ON) {
-			appbar.Push( 1,Catalog.GetString("You are IN, JUMP when prepared!!") );
+			feedbackMessage = Catalog.GetString("You are IN, JUMP when prepared!");
+			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 
 			loggedState = States.ON;
@@ -170,7 +176,8 @@ public class JumpExecute : EventExecute
 
 		
 		if (platformState==Chronopic.Plataforma.OFF) {
-			appbar.Push( 1,Catalog.GetString("You are OUT, JUMP when prepared!!") );
+			feedbackMessage = Catalog.GetString("You are OUT, JUMP when prepared!");
+			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 
 			loggedState = States.OFF;
@@ -235,15 +242,11 @@ public class JumpExecute : EventExecute
 				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) 
 				{
 					//has landed
-Log.Write("w1 ");				
-
 					if(hasFall && tc == 0) {
-Log.Write("w2 ");				
 						//jump with fall, landed first time
 						initializeTimer();
 
-Log.Write("w3 ");				
-						//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+						//app1.ProgressBarEventOrTimePreExecution(
 						//don't do it, put a boolean value and let the PulseGTK do it
 						updateProgressBar = new UpdateProgressBar (
 								true, //isEvent
@@ -251,7 +254,9 @@ Log.Write("w3 ");
 								1 //it's a drop: phase 1/3
 								);
 						needUpdateEventProgressBar = true;
-Log.Write("w4 ");				
+		
+						feedbackMessage = "";
+						needShowFeedbackMessage = true; 
 					} else {
 						//jump with fall: second landed; or without fall first landing
 					
@@ -270,8 +275,7 @@ Log.Write("w4 ");
 						if(hasFall)
 							percentageToPass = 3; //drop jump has three phases
 							
-Log.Write("w5 ");			
-						//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+						//app1.ProgressBarEventOrTimePreExecution(
 						//don't do it, put a boolean value and let the PulseGTK do it
 						updateProgressBar = new UpdateProgressBar (
 								true, //isEvent
@@ -279,7 +283,6 @@ Log.Write("w5 ");
 								percentageToPass
 								);
 						needUpdateEventProgressBar = true;
-Log.Write("w6 ");				
 					}
 					
 					loggedState = States.ON;
@@ -308,8 +311,7 @@ Log.Write("w6 ");
 						}
 
 						//update event progressbar
-Log.Write("w7 ");			
-						//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+						//app1.ProgressBarEventOrTimePreExecution(
 						//don't do it, put a boolean value and let the PulseGTK do it
 						updateProgressBar = new UpdateProgressBar (
 								true, //isEvent
@@ -317,15 +319,11 @@ Log.Write("w7 ");
 								2 //it's a drop jump: phase 2/3
 								);
 						needUpdateEventProgressBar = true;
-Log.Write("w8 ");				
 					} else {
-Log.Write("w9 ");				
 						initializeTimer();
 						
-Log.Write("wa ");				
-						
 						//update event progressbar
-						//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+						//app1.ProgressBarEventOrTimePreExecution(
 						//don't do it, put a boolean value and let the PulseGTK do it
 						updateProgressBar = new UpdateProgressBar (
 								true, //isEvent
@@ -333,7 +331,9 @@ Log.Write("wa ");
 								1 //normal jump, phase 1/2
 								);
 						needUpdateEventProgressBar = true;
-Log.Write("wb ");				
+						
+						feedbackMessage = "";
+						needShowFeedbackMessage = true; 
 					}
 
 					//change the automata state
@@ -359,7 +359,7 @@ Log.Write("wb ");
 	
 	protected override void updateTimeProgressBar() {
 		//has no finished, but move progressbar time
-		eventExecuteWin.ProgressBarEventOrTimePreExecution(
+		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
 				false, //activity mode
 				-1	//don't want to show info on label
@@ -375,18 +375,20 @@ Log.Write("wb ");
 		} else {
 			tc = 0;
 		}
-			
+		
+		/*	
 		string myStringPush =   
-			//Catalog.GetString("Last jump: ") + 
 			personName + " " + 
 			type + tcString + " " + Catalog.GetString("TF") + ": " + Util.TrimDecimals( tv.ToString(), pDN ) ;
 		if(weight > 0) {
 			myStringPush = myStringPush + "(" + weight.ToString() + "%)";
 		}
+		*/
 		if(simulated)
-			appbar.Push(1, Constants.SimulatedMessage);
+			feedbackMessage = Catalog.GetString(Constants.SimulatedMessage);
 		else
-			appbar.Push( 1,myStringPush );
+			feedbackMessage = "";
+		needShowFeedbackMessage = true; 
 
 		uniqueID = SqliteJump.Insert(false, Constants.JumpTable, "NULL", personID, sessionID, 
 				type, tv, tc, fall,  //type, tv, tc, fall
@@ -399,7 +401,7 @@ Log.Write("wb ");
 		//event will be raised, and managed in chronojump.cs
 		fakeButtonFinished.Click();
 		
-		prepareEventGraphJumpSimple = new PrepareEventGraphJumpSimple(tv, tc);
+		PrepareEventGraphJumpSimpleObject = new PrepareEventGraphJumpSimple(tv, tc);
 		needUpdateGraphType = eventType.JUMP;
 		needUpdateGraph = true;
 		
@@ -461,13 +463,14 @@ public class JumpRjExecute : JumpExecute
 	}
 
 	//jump execution
-	public JumpRjExecute(EventExecuteWindow eventExecuteWin, int personID, string personName, 
+	public JumpRjExecute(int personID, string personName, 
 			int sessionID, string type, double fall, double weight, 
 			double limitAsDouble, bool jumpsLimited, 
-			Chronopic cp, Gtk.Statusbar appbar, Gtk.Window app, int pDN, bool allowFinishAfterTime, 
-			bool volumeOn, RepetitiveConditionsWindow repetitiveConditionsWin)
+			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool allowFinishAfterTime, 
+			bool volumeOn, RepetitiveConditionsWindow repetitiveConditionsWin,
+			double progressbarLimit, ExecutingGraphData egd 
+			)
 	{
-		this.eventExecuteWin = eventExecuteWin;
 		this.personID = personID;
 		this.personName = personName;
 		this.sessionID = sessionID;
@@ -484,17 +487,21 @@ public class JumpRjExecute : JumpExecute
 		}
 		
 		this.cp = cp;
-		this.appbar = appbar;
+		this.event_execute_textview_message = event_execute_textview_message;
 		this.app = app;
 
 		this.pDN = pDN;
 		this.allowFinishAfterTime = allowFinishAfterTime;
 		this.volumeOn = volumeOn;
 		this.repetitiveConditionsWin = repetitiveConditionsWin;
+		this.progressbarLimit = progressbarLimit;
+		this.egd = egd;
 	
 		if(TypeHasFall) { hasFall = true; } 
 		else { hasFall = false; }
 		
+		fakeButtonUpdateGraph = new Gtk.Button();
+		fakeButtonEventEnded = new Gtk.Button();
 		fakeButtonFinished = new Gtk.Button();
 		
 		simulated = false;
@@ -534,11 +541,13 @@ public class JumpRjExecute : JumpExecute
 		bool success = false;
 
 		if (platformState==Chronopic.Plataforma.OFF && hasFall ) {
-			appbar.Push( 1,Catalog.GetString("You are OUT, JUMP when prepared!!") );
+			feedbackMessage = Catalog.GetString("You are OUT, JUMP when prepared!");
+			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 			success = true;
 		} else if (platformState==Chronopic.Plataforma.ON && ! hasFall ) {
-			appbar.Push( 1,Catalog.GetString("You are IN, JUMP when prepared!!") );
+			feedbackMessage = Catalog.GetString("You are IN, JUMP when prepared!");
+			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 			success = true;
 		} else {
@@ -638,6 +647,9 @@ public class JumpRjExecute : JumpExecute
 
 						//but start timer
 						initializeTimer();
+						
+						feedbackMessage = "";
+						needShowFeedbackMessage = true; 
 					} else {
 						//reactive jump has not finished... record the next jump
 						Log.WriteLine(string.Format("tcCount: {0}, tvCount: {1}", tcCount, tvCount));
@@ -662,7 +674,7 @@ public class JumpRjExecute : JumpExecute
 							tvCount = tvCount + 1;
 							
 							//update event progressbar
-							//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+							//app1.ProgressBarEventOrTimePreExecution(
 							updateProgressBar= new UpdateProgressBar (
 									true, //isEvent
 									jumpsLimited, //if jumpsLimited: do fraction; if time limited: do pulse
@@ -671,7 +683,7 @@ public class JumpRjExecute : JumpExecute
 							needUpdateEventProgressBar = true;
 							
 							//update graph
-							prepareEventGraphJumpReactive = new PrepareEventGraphJumpReactive(lastTv, lastTc, tvString, tcString);
+							PrepareEventGraphJumpReactiveObject = new PrepareEventGraphJumpReactive(lastTv, lastTc, tvString, tcString);
 							needUpdateGraphType = eventType.JUMPREACTIVE;
 							needUpdateGraph = true;
 
@@ -705,7 +717,7 @@ public class JumpRjExecute : JumpExecute
 							success = true;
 						
 							//update event progressbar
-							//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+							//app1.ProgressBarEventOrTimePreExecution(
 							updateProgressBar= new UpdateProgressBar (
 									true, //isEvent
 									true, //percentageMode
@@ -714,7 +726,7 @@ public class JumpRjExecute : JumpExecute
 							needUpdateEventProgressBar = true;
 							
 							//update graph
-							prepareEventGraphJumpReactive = new PrepareEventGraphJumpReactive(lastTv, lastTc, tvString, tcString);
+							PrepareEventGraphJumpReactiveObject = new PrepareEventGraphJumpReactive(lastTv, lastTc, tvString, tcString);
 							needUpdateGraphType = eventType.JUMPREACTIVE;
 							needUpdateGraph = true;
 						}
@@ -801,7 +813,7 @@ public class JumpRjExecute : JumpExecute
 	}
 	
 	protected override void updateProgressBarForFinish() {
-		eventExecuteWin.ProgressBarEventOrTimePreExecution(
+		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
 				true, //percentageMode: it has finished, show bar at 100%
 				//limitAsDouble
@@ -814,14 +826,14 @@ public class JumpRjExecute : JumpExecute
 
 		if(firstRjValue)  
 			//until it has not landed for first time, show a pulse with no values
-			eventExecuteWin.ProgressBarEventOrTimePreExecution(
+			progressBarEventOrTimePreExecution(
 					false, //isEvent false: time
 					false, //activity mode
 					-1	//don't want to show info on label
 					); 
 		else
 			//after show a progressBar with time value
-			eventExecuteWin.ProgressBarEventOrTimePreExecution(
+			progressBarEventOrTimePreExecution(
 					false, //isEvent false: time
 					!jumpsLimited, //if jumpsLimited: activity, if timeLimited: fraction
 					timerCount
@@ -872,7 +884,7 @@ public class JumpRjExecute : JumpExecute
 			}
 			if(deletedEvent) {
 				//update graph if a event was deleted
-				prepareEventGraphJumpReactive = new PrepareEventGraphJumpReactive(Util.GetLast(tvString), Util.GetLast(tcString), tvString, tcString);
+				PrepareEventGraphJumpReactiveObject = new PrepareEventGraphJumpReactive(Util.GetLast(tvString), Util.GetLast(tcString), tvString, tcString);
 				needUpdateGraphType = eventType.JUMPREACTIVE;
 				needUpdateGraph = true;
 
@@ -972,22 +984,24 @@ public class JumpRjExecute : JumpExecute
 
 
 			//event will be raised, and managed in chronojump.cs
+			/*
 			string myStringPush =   
 				//Catalog.GetString("Last jump: ") + 
 				personName + " " + 
 				type + " (" + limitString + ") " +
 				" " + Catalog.GetString("AVG TF") + ": " + Util.TrimDecimals( Util.GetAverage (tvString).ToString(), pDN ) +
 				" " + Catalog.GetString("AVG TC") + ": " + Util.TrimDecimals( Util.GetAverage (tcString).ToString(), pDN ) ;
+			*/
 			if(simulated)
-				appbar.Push(1, Constants.SimulatedMessage);
+				feedbackMessage = Catalog.GetString(Constants.SimulatedMessage);
 			else
-				appbar.Push(1, myStringPush );
+				feedbackMessage = "";
+			needShowFeedbackMessage = true; 
 		
 
 			//event will be raised, and managed in chronojump.cs
 			fakeButtonFinished.Click();
 
-			//eventExecuteWin.EventEnded();
 			needEndEvent = true; //used for hiding some buttons on eventWindow, and also for updateTimeProgressBar here
 		}
 	}
