@@ -23,9 +23,11 @@ using Gtk;
 using Glade;
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
-
+using System.IO;
 using System.Threading;
 using Mono.Unix;
+using LongoMatch.Gui;
+using LongoMatch.Video.Player;
 
 
 //--------------------------------------------------------
@@ -40,25 +42,35 @@ public class EditEventWindow
 	[Widget] protected Gtk.Label label_header;
 	[Widget] protected Gtk.Label label_type_title;
 	[Widget] protected Gtk.Label label_type_value;
+	[Widget] protected Gtk.Label label_run_start_title;
+	[Widget] protected Gtk.Label label_run_start_value;
 	[Widget] protected Gtk.Label label_event_id_value;
 	[Widget] protected Gtk.Label label_tv_title;
 	[Widget] protected Gtk.Entry entry_tv_value;
+	[Widget] protected Gtk.Label label_tv_units;
 	[Widget] protected Gtk.Label label_tc_title;
 	[Widget] protected Gtk.Entry entry_tc_value;
+	[Widget] protected Gtk.Label label_tc_units;
 	[Widget] protected Gtk.Label label_fall_title;
 	[Widget] protected Gtk.Entry entry_fall_value;
+	[Widget] protected Gtk.Label label_fall_units;
 	[Widget] protected Gtk.Label label_distance_title;
 	[Widget] protected Gtk.Entry entry_distance_value;
+	[Widget] protected Gtk.Label label_distance_units;
 	[Widget] protected Gtk.Label label_time_title;
 	[Widget] protected Gtk.Entry entry_time_value;
+	[Widget] protected Gtk.Label label_time_units;
 	[Widget] protected Gtk.Label label_speed_title;
 	[Widget] protected Gtk.Label label_speed_value;
+	[Widget] protected Gtk.Label label_speed_units;
 	[Widget] protected Gtk.Label label_weight_title;
 	[Widget] protected Gtk.Entry entry_weight_value;
+	[Widget] protected Gtk.Label label_weight_units;
 	[Widget] protected Gtk.Label label_limited_title;
 	[Widget] protected Gtk.Label label_limited_value;
 	[Widget] protected Gtk.Label label_angle_title;
 	[Widget] protected Gtk.Entry entry_angle_value;
+	[Widget] protected Gtk.Label label_angle_units;
 	[Widget] protected Gtk.Label label_simulated;
 	
 	[Widget] protected Gtk.Box hbox_combo_eventType;
@@ -68,6 +80,11 @@ public class EditEventWindow
 	
 	[Widget] protected Gtk.Label label_mistakes;
 	[Widget] protected Gtk.SpinButton spin_mistakes;
+
+	[Widget] protected Gtk.Label label_video_yes;
+	[Widget] protected Gtk.Label label_video_no;
+	[Widget] protected Gtk.Button button_video_watch;
+	protected string videoFileName = "";
 	
 	[Widget] protected Gtk.Entry entry_description;
 	//[Widget] protected Gtk.TextView textview_description;
@@ -86,7 +103,9 @@ public class EditEventWindow
 	protected string entryWeight = "0"; //used to record the % for old person if we change it
 	protected string entryAngle = "0";
 
+	protected Constants.TestTypes typeOfTest;
 	protected bool showType;
+	protected bool showRunStart;
 	protected bool showTv;
 	protected bool showTc;
 	protected bool showFall;
@@ -134,7 +153,9 @@ public class EditEventWindow
 }
 	
 	protected virtual void initializeValues () {
+		typeOfTest = Constants.TestTypes.JUMP;
 		showType = true;
+		showRunStart = false;
 		showTv = true;
 		showTc = true;
 		showFall = true;
@@ -166,6 +187,7 @@ public class EditEventWindow
 		else { 
 			label_tv_title.Hide();
 			entry_tv_value.Hide();
+			label_tv_units.Hide();
 		}
 
 		if(showTc)
@@ -173,6 +195,7 @@ public class EditEventWindow
 		else { 
 			label_tc_title.Hide();
 			entry_tc_value.Hide();
+			label_tc_units.Hide();
 		}
 
 		if(showFall)
@@ -180,6 +203,7 @@ public class EditEventWindow
 		else { 
 			label_fall_title.Hide();
 			entry_fall_value.Hide();
+			label_fall_units.Hide();
 		}
 
 		if(showDistance)
@@ -187,6 +211,7 @@ public class EditEventWindow
 		else { 
 			label_distance_title.Hide();
 			entry_distance_value.Hide();
+			label_distance_units.Hide();
 		}
 
 		if(showTime)
@@ -194,6 +219,7 @@ public class EditEventWindow
 		else { 
 			label_time_title.Hide();
 			entry_time_value.Hide();
+			label_time_units.Hide();
 		}
 
 		if(showSpeed)
@@ -201,6 +227,7 @@ public class EditEventWindow
 		else { 
 			label_speed_title.Hide();
 			label_speed_value.Hide();
+			label_speed_units.Hide();
 		}
 
 		if(showWeight)
@@ -208,6 +235,7 @@ public class EditEventWindow
 		else { 
 			label_weight_title.Hide();
 			entry_weight_value.Hide();
+			label_weight_units.Hide();
 		}
 
 		if(showLimited)
@@ -222,6 +250,7 @@ public class EditEventWindow
 		else { 
 			label_angle_title.Hide();
 			entry_angle_value.Hide();
+			label_angle_units.Hide();
 		}
 		
 		if(! showMistakes) {
@@ -240,6 +269,13 @@ public class EditEventWindow
 			label_type_title.Hide();
 			combo_eventType.Hide();
 		}
+		
+		if(showRunStart) 
+			fillRunStart(myEvent);
+		else {
+			label_run_start_title.Hide();
+			label_run_start_value.Hide();
+		}
 
 		ArrayList persons = SqlitePersonSession.SelectCurrentSessionPersons(myEvent.SessionID);
 		string [] personsStrings = new String[persons.Count];
@@ -255,6 +291,34 @@ public class EditEventWindow
 			
 		hbox_combo_person.PackStart(combo_persons, true, true, 0);
 		hbox_combo_person.ShowAll();
+
+		//show video if available	
+		videoFileName = Util.GetVideoFileName(myEvent.SessionID, typeOfTest, myEvent.UniqueID);
+		if(File.Exists(videoFileName)) {
+			label_video_yes.Visible = true;
+			label_video_no.Visible = false;
+			button_video_watch.Sensitive = true;
+		} else {
+			label_video_yes.Visible = false;
+			label_video_no.Visible = true;
+			button_video_watch.Sensitive = false;
+		}
+	}
+
+	private void on_button_video_watch_clicked (object o, EventArgs args) {
+		if(File.Exists(videoFileName)) { 
+			Log.WriteLine("Exists and clicked " + videoFileName);
+			
+			PlayerBin player = new PlayerBin();
+			player.Open(videoFileName);
+
+			Gtk.Window d = new Gtk.Window(Catalog.GetString("Playing video"));
+			d.Add(player);
+			d.Modal = true;
+			d.ShowAll();
+			d.DeleteEvent += delegate(object sender, DeleteEventArgs e) {player.Close(); player.Dispose();};
+			player.Play(); 
+		}
 	}
 	
 	protected void fillWindowTitleAndLabelHeader() {
@@ -308,6 +372,9 @@ public class EditEventWindow
 	protected virtual void fillFall(Event myEvent) {
 	}
 
+	protected virtual void fillRunStart(Event myEvent) {
+	}
+
 	protected virtual void fillDistance(Event myEvent) {
 		/*
 		Run myRun = (Run) myEvent;
@@ -465,7 +532,7 @@ public class EditEventWindow
 		EditEventWindowBox.edit_event.Hide();
 		EditEventWindowBox = null;
 	}
-	
+
 	void on_button_accept_clicked (object o, EventArgs args)
 	{
 		int eventID = Convert.ToInt32 ( label_event_id_value.Text );
@@ -585,13 +652,6 @@ public class EventMoreWindow
 	
 	void on_button_delete_type_clicked (object o, EventArgs args)
 	{
-		/*
-		//search for events of that type on db
-		if(selectedEventType == EventType.Types.JUMP.ToString())
-			tests = SqliteJump.SelectJumps(-1, -1, "", selectedEventName); 
-		else //RUN
-			tests = SqliteRun.SelectRuns(-1, -1, selectedEventName); 
-		*/
 		string [] tests = findTestTypesInSessions();
 
 		//this will be much better doing a select distinct(session) instead of using SelectJumps or Runs
@@ -613,12 +673,13 @@ public class EventMoreWindow
 		}
 	}
 	
+
+	protected virtual void deleteTestLine() {
+	}
+	
 	protected void on_button_delete_type_accepted (object o, EventArgs args)
 	{
-		if(selectedEventType == EventType.Types.JUMP.ToString())
-			SqliteJumpType.Delete(selectedEventName, false);
-		else //RUN
-			SqliteRunType.Delete(selectedEventName);
+		deleteTestLine();
 
 		TreeModel model;
 		TreeIter iter;
@@ -640,24 +701,20 @@ public class EventMoreWindow
 		get { return button_selected; }
 	}
 
-	public Button Button_accept 
-	{
-		set {
-			button_accept = value;	
-		}
-		get {
-			return button_accept;
-		}
+	public Button Button_accept {
+		set { button_accept = value; }
+		get { return button_accept; }
+	}
+	
+	public Button Button_cancel {
+		set { button_cancel = value; }
+		get { return button_cancel; }
 	}
 	
 	public string SelectedEventName
 	{
-		set {
-			selectedEventName = value;	
-		}
-		get {
-			return selectedEventName;
-		}
+		set { selectedEventName = value; }
+		get { return selectedEventName; }
 	}
 	
 	public string SelectedDescription {
