@@ -27,7 +27,10 @@ using System.Text; //StringBuilder
 using System.Collections; //ArrayList
 using Mono.Unix;
 using System.Threading;
-
+using System.IO; 
+using LongoMatch.Gui;
+using LongoMatch.Video.Capturer;
+using LongoMatch.Video.Common;
 
 //load person (jumper)
 public class PersonRecuperateWindow {
@@ -58,6 +61,7 @@ public class PersonRecuperateWindow {
 	protected int columnId = 0;
 	protected int firstColumn = 0;
 	protected int pDN;
+	protected bool videoOn;
 	
 	public Gtk.Button fakeButtonDone;
 
@@ -94,12 +98,13 @@ public class PersonRecuperateWindow {
 		treeview_person_recuperate.Selection.Changed += onSelectionEntry;
 	}
 	
-	static public PersonRecuperateWindow Show (Gtk.Window parent, Session currentSession, int pDN)
+	static public PersonRecuperateWindow Show (Gtk.Window parent, Session currentSession, int pDN, bool videoOn)
 	{
 		if (PersonRecuperateWindowBox == null) {
 			PersonRecuperateWindowBox = new PersonRecuperateWindow (parent, currentSession);
 		}
 		PersonRecuperateWindowBox.pDN = pDN;
+		PersonRecuperateWindowBox.videoOn = videoOn;
 
 		PersonRecuperateWindowBox.person_recuperate.Show ();
 		
@@ -109,11 +114,11 @@ public class PersonRecuperateWindow {
 	protected void createTreeView (Gtk.TreeView tv, int count) {
 		tv.HeadersVisible=true;
 		
-		UtilGtk.CreateCols(tv, store, Catalog.GetString("ID"), count++);
-		UtilGtk.CreateCols(tv, store, Catalog.GetString("Name"), count++);
-		UtilGtk.CreateCols(tv, store, Catalog.GetString("Sex"), count++);
-		UtilGtk.CreateCols(tv, store, Catalog.GetString("Date of Birth"), count++);
-		UtilGtk.CreateCols(tv, store, Catalog.GetString("Description"), count++);
+		UtilGtk.CreateCols(tv, store, Catalog.GetString("ID"), count++, true);
+		UtilGtk.CreateCols(tv, store, Catalog.GetString("Name"), count++, true);
+		UtilGtk.CreateCols(tv, store, Catalog.GetString("Sex"), count++, true);
+		UtilGtk.CreateCols(tv, store, Catalog.GetString("Date of Birth"), count++, true);
+		UtilGtk.CreateCols(tv, store, Catalog.GetString("Description"), count++, true);
 
 		//sort non textual cols	
 		store.SetSortFunc (firstColumn + 0, UtilGtk.IdColumnCompare);
@@ -247,7 +252,7 @@ public class PersonRecuperateWindow {
 			Person person = SqlitePerson.Select(Convert.ToInt32(selected));
 
 			personAddModifyWin = PersonAddModifyWindow.Show(
-					parent, currentSession, person, pDN, true); //comes from recuperate window
+					parent, currentSession, person, pDN, true, videoOn); //comes from recuperate window
 			personAddModifyWin.FakeButtonAccept.Clicked += new EventHandler(on_edit_current_person_accepted);
 		}
 	}
@@ -323,6 +328,7 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		
 		//put an icon to window
 		UtilGtk.IconWindow(person_recuperate);
+		person_recuperate.Title = Catalog.GetString("Load persons from other session");
 
 	
 		//this class doesn't allow to search by name
@@ -360,13 +366,14 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		treeview_person_recuperate.Selection.Changed += onSelectionEntry;
 	}
 
-	static public new PersonsRecuperateFromOtherSessionWindow Show (Gtk.Window parent, Session currentSession)
+	static public new PersonsRecuperateFromOtherSessionWindow Show (Gtk.Window parent, Session currentSession, bool videoOn)
 	{
 		if (PersonsRecuperateFromOtherSessionWindowBox == null) {
 			PersonsRecuperateFromOtherSessionWindowBox = 
 				new PersonsRecuperateFromOtherSessionWindow (parent, currentSession);
 		}
 		PersonsRecuperateFromOtherSessionWindowBox.person_recuperate.Show ();
+		PersonsRecuperateFromOtherSessionWindowBox.videoOn = videoOn;
 		
 		return PersonsRecuperateFromOtherSessionWindowBox;
 	}
@@ -567,7 +574,7 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 					Person person = SqlitePerson.Select(
 							Convert.ToInt32(treeview_person_recuperate.Model.GetValue(iter, 1)) );
 					personAddModifyWin = PersonAddModifyWindow.Show(
-							parent, currentSession, person, pDN, true); //comes from recuperate window
+							parent, currentSession, person, pDN, true, videoOn); //comes from recuperate window
 					PersonAddModifyWindow.MakeVisible();
 					personAddModifyWin.FakeButtonAccept.Clicked += new EventHandler(on_edit_current_person_accepted);
 					personAddModifyWin.FakeButtonCancel.Clicked += new EventHandler(on_edit_current_person_cancelled);
@@ -598,12 +605,17 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 					Convert.ToInt32(myStringFull[0]) //select from this session (on combo_sessions)
 				    );
 
-			if(inserted == 1)
-				statusbar1.Push( 1, Catalog.GetString("Loaded") + " " + currentPerson.Name );
-			else //more inserted
-				statusbar1.Push( 1, string.Format(Catalog.GetString("Successfully added {0} persons"), inserted));
-
-			fakeButtonDone.Click();
+			if(inserted >= 1) {
+				if(inserted == 1)
+					statusbar1.Push( 1, Catalog.GetString("Loaded") + " " + currentPerson.Name );
+				else 
+					statusbar1.Push( 1, string.Format(Catalog.GetPluralString(
+									"Successfully added one person.",
+									"Successfully added {0} persons.",
+									inserted),
+								inserted));
+				fakeButtonDone.Click();
+			}
 		}
 	
 		//check if there are rows checked for having sensitive or not in recuperate button
@@ -630,9 +642,10 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		{
 			currentRow ++;
 			
-			Log.WriteLine("To sleep in order AddMoidfyWin gets closed, in order to open again");
+			Log.WriteLine("To sleep in order AddModifyWin gets closed, in order to open again");
 			System.Threading.Thread.Sleep (100);
 			Log.WriteLine("done");
+			inserted --;
 			processRow();
 		}
 	}
@@ -733,7 +746,7 @@ public class PersonNotUploadWindow : PersonsRecuperateFromOtherSessionWindow
 		foreach (Person person in myPersons) {
 			store.AppendValues (
 					! Util.FoundInArrayList(initiallyUnchecked, person.UniqueID.ToString()), 
-					person.UniqueID, 
+					person.UniqueID.ToString(), 
 					person.Name, 
 					getCorrectSex(person.Sex), 
 					person.DateBorn.ToShortDateString(), 
@@ -841,6 +854,11 @@ public class PersonAddModifyWindow
 	[Widget] Gtk.Image image_sport;
 	[Widget] Gtk.Image image_speciallity;
 	[Widget] Gtk.Image image_level;
+	
+	[Widget] Gtk.Button button_zoom;
+	[Widget] Gtk.Image image_photo_mini;
+	[Widget] Gtk.Image image_zoom;
+	[Widget] Gtk.Button button_take_photo;
 
 	[Widget] Gtk.Button button_accept;
 	[Widget] Gtk.Button button_cancel;
@@ -917,8 +935,31 @@ public class PersonAddModifyWindow
 		createComboCountries();
 		
 		Pixbuf pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "calendar.png");
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "calendar.png"); //from asssembly
 		image_calendar.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameZoomInIcon);
+		image_zoom.Pixbuf = pixbuf;
+
+		string photoFile = Util.GetPhotoFileName(true, currentPerson.UniqueID);
+		if(File.Exists(photoFile)) {
+			try {
+				pixbuf = new Pixbuf (photoFile); //from a file
+				image_photo_mini.Pixbuf = pixbuf;
+			} catch {
+				//on windows there are problem using the fileNames that are not on temp
+				string tempFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
+					Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
+				File.Copy(photoFile, tempFileName, true);
+				pixbuf = new Pixbuf (tempFileName);
+				image_photo_mini.Pixbuf = pixbuf;
+			}
+		}
+		//show zoom button only if big image exists
+		if(File.Exists(Util.GetPhotoFileName(false, currentPerson.UniqueID)))
+			button_zoom.Sensitive = true;
+		else
+			button_zoom.Sensitive = false;
 			
 		fakeButtonAccept = new Gtk.Button();
 		fakeButtonCancel = new Gtk.Button();
@@ -930,6 +971,89 @@ public class PersonAddModifyWindow
 			person_win.Title = Catalog.GetString ("Edit jumper");
 	}
 	
+	void on_button_zoom_clicked (object o, EventArgs args) {
+		string tempFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoTemp +
+				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
+		if(! adding) {
+			//on windows there are problem using the fileNames that are not on temp
+			string fileName = Util.GetPhotoFileName(false, currentPerson.UniqueID);
+			File.Copy(fileName, tempFileName, true);
+		}
+
+		new DialogImageTest(currentPerson.Name, tempFileName);
+	}
+
+	Gtk.Window capturerWindow;
+	CapturerBin capturer;
+	void on_button_take_photo_clicked (object o, EventArgs args) 
+	{
+		capturer = new CapturerBin();
+		CapturePropertiesStruct s = new CapturePropertiesStruct();
+
+		s.CaptureSourceType = CaptureSourceType.Raw;
+
+		capturer.CaptureProperties = s;
+		capturer.Type = CapturerType.Snapshot;
+		capturer.Visible=true;
+		capturer.NewSnapshot += on_snapshot_done;
+		capturer.NewSnapshotMini += on_snapshot_mini_done;
+		
+ 		capturerWindow = new Gtk.Window("Capturer");
+		capturerWindow.Add(capturer);
+		capturerWindow.Modal=true;
+
+		person_win.Hide();
+
+		capturerWindow.ShowAll();
+		capturerWindow.Present();
+		capturerWindow.DeleteEvent += delegate(object sender, DeleteEventArgs e) {capturer.Close(); capturer.Dispose(); person_win.Show(); };
+		capturer.Run();
+	}
+
+	private void on_snapshot_done(Pixbuf pixbuf) {
+		string fileName = Path.Combine(Path.GetTempPath(), Constants.PhotoTemp +
+				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
+		
+		pixbuf.Save(fileName,"jpeg");
+		
+		//on windows there are problem using the fileNames that are not on temp
+		if(!adding)
+			File.Copy(fileName, Util.GetPhotoFileName(false, currentPerson.UniqueID), true); //overwrite
+
+		button_zoom.Sensitive = true;
+	}
+
+	private void on_snapshot_mini_done(Pixbuf pixbuf) {
+		string tempSmallFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
+				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
+		
+		pixbuf.Save(tempSmallFileName,"jpeg");
+		
+		//on windows there are problem using the fileNames that are not on temp
+		if(!adding)
+			File.Copy(tempSmallFileName, Util.GetPhotoFileName(true, currentPerson.UniqueID), true); //overwrite
+		
+		capturer.Close();
+		capturer.Dispose();
+		capturerWindow.Hide();
+
+		person_win.Show();
+
+
+		string tempFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
+			Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
+		if(!adding) {
+			//on windows there are problem using the fileNames that are not on temp
+			string fileName = Util.GetPhotoFileName(true, currentPerson.UniqueID);
+			File.Copy(fileName, tempFileName, true);
+		}
+		
+		if(File.Exists(tempFileName)) {
+			Pixbuf pixbuf2 = new Pixbuf (tempFileName); //from a file
+			image_photo_mini.Pixbuf = pixbuf2;
+		}
+	}
+
 	void on_entries_required_changed (object o, EventArgs args)
 	{
 		bool allOk = true;
@@ -999,7 +1123,7 @@ public class PersonAddModifyWindow
 	}
 	
 	static public PersonAddModifyWindow Show (Gtk.Window parent, 
-			Session mySession, Person currentPerson, int pDN, bool comesFromRecuperateWin)
+			Session mySession, Person currentPerson, int pDN, bool comesFromRecuperateWin, bool videoOn)
 	{
 		if (comesFromRecuperateWin) 
 			PersonAddModifyWindowBox = null;
@@ -1011,8 +1135,12 @@ public class PersonAddModifyWindow
 		PersonAddModifyWindowBox.pDN = pDN;
 		PersonAddModifyWindowBox.comesFromRecuperateWin = comesFromRecuperateWin;
 
-		if(comesFromRecuperateWin)
-			PersonAddModifyWindowBox.button_cancel.Hide();
+		PersonAddModifyWindowBox.button_take_photo.Sensitive = videoOn;
+
+		//No more hide cancel button.
+		//Better to show it and allow to not recuperate if user changes his mind
+		//if(comesFromRecuperateWin)
+			//PersonAddModifyWindowBox.button_cancel.Hide();
 		
 		PersonAddModifyWindowBox.person_win.Show ();
 		
@@ -1497,7 +1625,7 @@ public class PersonAddModifyWindow
 		string [] myMargarias = SqliteRun.SelectRuns(currentSession.UniqueID, currentPerson.UniqueID, "Margaria");
 		foreach(string myStr in myMargarias) {
 			string [] margaria = myStr.Split(new char[] {':'});
-			Run mRun = SqliteRun.SelectRunData(Convert.ToInt32(margaria[1]));
+			Run mRun = SqliteRun.SelectRunData(Convert.ToInt32(margaria[1]), false);
 			double distanceMeters = mRun.Distance / 1000;
 			mRun.Description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMeters / mRun.Time).ToString(), pDN) + " (Watts)";
 			SqliteRun.Update(mRun.UniqueID, mRun.Type, mRun.Distance.ToString(), mRun.Time.ToString(), mRun.PersonID, mRun.Description);
@@ -1738,7 +1866,7 @@ public class PersonAddMultipleWindow {
 			table_main.Attach (sexBox, (uint) 2, (uint) 3, (uint) count, (uint) count +1);
 
 
-			Gtk.SpinButton mySpin = new Gtk.SpinButton(0, 300, 1);
+			Gtk.SpinButton mySpin = new Gtk.SpinButton(0, 300, .1);
 			table_main.Attach (mySpin, (uint) 3, (uint) 4, (uint) count, (uint) count +1);
 			mySpin.Show();
 			spins.Add(mySpin);
@@ -1844,7 +1972,7 @@ public class PersonAddMultipleWindow {
 				insertPerson (
 						((Gtk.Entry)entries[i]).Text.ToString(), 
 						((Gtk.RadioButton)radiosM[i]).Active, 
-		 				(int) ((Gtk.SpinButton)spins[i]).Value);
+		 				(double) ((Gtk.SpinButton)spins[i]).Value);
 	}
 
 	void insertPerson (string name, bool male, double weight) 
