@@ -78,7 +78,12 @@ class SqliteJumpRj : SqliteJump
 				jumps + ", " + Util.ConvertToPoint(time) + ", '" + limited + "', '" + angleString + "', " + simulated +")" ;
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
-		int myLast = dbcon.LastInsertRowId;
+
+		//int myLast = dbcon.LastInsertRowId;
+		//http://stackoverflow.com/questions/4341178/getting-the-last-insert-id-with-sqlite-net-in-c
+		string myString = @"select last_insert_rowid()";
+		dbcmd.CommandText = myString;
+		int myLast = Convert.ToInt32(dbcmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
 
 		if(! dbconOpened)
 			dbcon.Close();
@@ -167,11 +172,12 @@ class SqliteJumpRj : SqliteJump
 		return myJumps;
 	}
 
-	public static JumpRj SelectJumpData(string tableName, int uniqueID)
+	public static JumpRj SelectJumpData(string tableName, int uniqueID, bool dbconOpened)
 	{
 		//tableName is jumpRj or tempJumpRj
 
-		dbcon.Open();
+		if(!dbconOpened)
+			dbcon.Open();
 
 		dbcmd.CommandText = "SELECT * FROM " + tableName + " WHERE uniqueID == " + uniqueID;
 		
@@ -184,7 +190,9 @@ class SqliteJumpRj : SqliteJump
 
 		JumpRj myJump = new JumpRj(DataReaderToStringArray(reader, 18));
 
-		dbcon.Close();
+		reader.Close();
+		if(!dbconOpened)
+			dbcon.Close();
 		return myJump;
 	}
 	
@@ -225,6 +233,7 @@ class SqliteJumpRj : SqliteJump
 						reader[3].ToString(), reader[4].ToString()));
 			}
 		}
+		reader.Close();
 		dbcon.Close();
 	}
 
