@@ -54,7 +54,7 @@ public class Stat
 	protected ArrayList sessions;
 	protected int dataColumns; //for SimpleSession
 	
-	protected string jumpType;
+	protected string jumpType; //mean also runType
 	protected bool showSex;
 	protected int statsJumpsType;
 	protected int limit;
@@ -81,9 +81,9 @@ public class Stat
 
 	//for toString() in every stat
 	protected string allValuesString = Catalog.GetString("All values");
-	protected string avgValuesString = Catalog.GetString("Avg values of each jumper");
+	protected string avgValuesString = Catalog.GetString("Avg values of each person");
 	
-	protected int numContinuous; //for stats rj evolution
+	protected int numContinuous; //for stats rj evolution and runIntervallic
 	
 	//for raise a signal and manage it on src/gui/stats.cs
 	//signal will be catched first in src/statType.cs and there a equal signal will be raised
@@ -424,6 +424,22 @@ public class Stat
 		return newStr;		
 	}
 	
+	protected string obtainSessionSqlStringTwoTests(ArrayList sessions)
+	{
+		string newStr = "WHERE (";
+		for (int i=0; i < sessions.Count; i++) {
+			string [] stringFullResults = sessions[i].ToString().Split(new char[] {':'});
+			newStr = newStr + " (j1.sessionID == " + stringFullResults[0] +
+				" AND j2.sessionID == " + stringFullResults[0] + ")";
+			if (i+1 < sessions.Count) {
+				newStr = newStr + " OR ";
+			}
+		}
+		newStr = newStr + ") ";
+		return newStr;
+	}
+
+	
 	public virtual void PrepareData () {
 	}
 
@@ -850,6 +866,7 @@ public class Stat
 	protected ArrayList GraphSeries = new ArrayList();
 
 	protected bool isRjEvolution = false; //needed because in RjEvolution graph, series are treaten in a different way
+	protected bool isRunIntervalEvolution = false; //small differences with isRjEvolution
 	int rjEvolutionMaxJumps; //we should care of maxjumps of the checked rjEvolution rows
 
 	
@@ -940,7 +957,7 @@ public class Stat
 					continue;
 				
 				if(val == "-") 
-					rD += sep + "0";
+					rD += sep + "NA";
 				else
 					rD += sep + Util.ConvertToPoint(val);
 				sep = ", ";
@@ -1015,10 +1032,17 @@ public class Stat
 				continue;
 			}
 
-			//in isRjEvolution then check it this serie will be shown (each jumper has a TC and a TF serie)
-			if( ! acceptCheckedData( divideAndRoundDown(countSeries)) ) {
-				countSeries ++;
-				continue;
+			//in isRjEvolution then check if this serie will be shown (each jumper has a TC and a TF serie)
+			if(isRjEvolution) {
+				if( ! acceptCheckedData( divideAndRoundDown(countSeries)) ) {
+					countSeries ++;
+					continue;
+				}
+			} else {
+				if(! acceptCheckedData(countSeries)) {
+					countSeries ++;
+					continue;
+				}
 			}
 
 			rD += "serie" + count.ToString() + " <- c(";
@@ -1051,9 +1075,16 @@ public class Stat
 		int i=0;
 		string sep2 = "";
 		foreach(GraphSerie serie in GraphSeries) {
-			if(acceptCheckedData(divideAndRoundDown(i++))) {
-				colNamesD += sep2 + "'" + serie.Title + "'";
-				sep2 = ", ";
+			if(isRjEvolution) {
+				if(acceptCheckedData(divideAndRoundDown(i++))) {
+					colNamesD += sep2 + "'" + serie.Title + "'";
+					sep2 = ", ";
+				}
+			} else {
+				if(acceptCheckedData(i++)) {
+					colNamesD += sep2 + "'" + serie.Title + "'";
+					sep2 = ", ";
+				}
 			}
 		}
 		//create rows
@@ -1138,7 +1169,7 @@ public class Stat
 		string rG = //rGraphString
 		   	" colors=" + gro.Palette +"(length(rownames(data)))\n" +
 			"barplot(data, beside=T, col=colors, lwd="+ gro.LineWidth +", las=2, xlab=''" + ylabStr + ")\n" +
-			" legend('" + gro.Legend +"', legend=rownames(data), cex=.7, col=colors, pch=3)\n";
+			" legend('" + gro.Legend +"', legend=rownames(data), cex=.7, col=colors, pch=15)\n";
 		
 		//have an unique title for both graphs
 		string titStr = getTitle("Barplot","");
@@ -1157,7 +1188,7 @@ public class Stat
 
 	private string getRLinesString(GraphROptions gro, string fileName, Sides side) {
 		string allData = "";
-		if(isRjEvolution)
+		if(isRjEvolution || isRunIntervalEvolution)
 			allData = convertDataToROnRjEvolution(gro, side);
 		else
 			allData = convertDataToR(gro, side);
@@ -1175,12 +1206,10 @@ public class Stat
 				ylabStr = ", ylab='" + Util.RemoveTilde(CurrentGraphData.LabelLeft) + "'";
 		}
 
-		string naString = "";
-		if(isRjEvolution)
-			naString = ", na.rm = TRUE";
+		string naString = ", na.rm = TRUE";
 
 		string xlimString = "c(0,length(colnames(data))+1)";
-		if(isRjEvolution)
+		if(isRjEvolution || isRunIntervalEvolution)
 			xlimString = "c(1," + rjEvolutionMaxJumps + ")";
 	
 		//TC and TF same color on rjEvo	
@@ -1196,7 +1225,7 @@ public class Stat
 			colors="'black'";
 			gro.Palette="gray.colors";
 			changedPalette = true;
-		} else if(isRjEvolution)
+		} else if(isRjEvolution) //runIntervalEvolution doesn't have this because only has one serie
 			colorsConversionString = "for(i in 2:length(colors)) if(i%%2 == 0) colors[i]=colors[i-1]\n";
 
 		string rG = //rGraphString
@@ -1308,10 +1337,10 @@ public class Stat
 		string rG = //rGraphString
 			
 			"hist(serie0, main='', lwd="+ gro.LineWidth +", xlab=colnames(data)[1], cex=1)\n" +
-			"abline(v=mean(serie0), lwd="+ gro.LineWidth +", lty=1, col='grey20')\n" +
-			"abline(v=median(serie0), lwd="+ gro.LineWidth +", lty=2, col='grey40')\n" +
-			"mtext('avg', at=mean(serie0), side=3, cex=.7, col='grey20')\n" +
-			"mtext('median', at=median(serie0), side=1, cex=.7, col='grey40')\n" +
+			"abline(v=mean(serie0, na.rm=T), lwd="+ gro.LineWidth +", lty=1, col='grey20')\n" +
+			"abline(v=median(serie0, na.rm=T), lwd="+ gro.LineWidth +", lty=2, col='grey40')\n" +
+			"mtext('avg', at=mean(serie0, na.rm=T), side=3, cex=.7, col='grey20')\n" +
+			"mtext('median', at=median(serie0, na.rm=T), side=1, cex=.7, col='grey40')\n" +
 			titStr;
 
 		return allData + rG;
@@ -1322,10 +1351,10 @@ public class Stat
 		string titStr = getTitle("Dotchart","");
 		string rG = //rGraphString
 			"dotchart(serie0, labels=rownames(data), xlab=colnames(data)[1], lwd="+ gro.LineWidth +", cex=1)\n" +
-			"abline(v=mean(serie0), lwd="+ gro.LineWidth +", lty=1, col='grey20')\n" +
-			"abline(v=median(serie0), lwd="+ gro.LineWidth +", lty=2, col='grey40')\n" +
-			"mtext('avg', at=mean(serie0), side=3, cex=.7, col='grey20')\n" +
-			"mtext('median', at=median(serie0), side=1, cex=.7, col='grey40')\n" +
+			"abline(v=mean(serie0, na.rm=T), lwd="+ gro.LineWidth +", lty=1, col='grey20')\n" +
+			"abline(v=median(serie0, na.rm=T), lwd="+ gro.LineWidth +", lty=2, col='grey40')\n" +
+			"mtext('avg', at=mean(serie0, na.rm=T), side=3, cex=.7, col='grey20')\n" +
+			"mtext('median', at=median(serie0, na.rm=T), side=1, cex=.7, col='grey40')\n" +
 			titStr;
 
 		return allData + rG;
@@ -1358,10 +1387,14 @@ public class Stat
 		//a file path uses Unix-like path separator '/'		
 		fileName = fileName.Replace("\\","/");
 		
+		string cexAxisString = "";
+		if(gRO.Type == Constants.GraphTypeBarplot || gRO.Type == Constants.GraphTypeLines) 
+			cexAxisString = ", cex.axis=" + Util.ConvertToPoint(gRO.XAxisFontSize);
+		
 		string rString = "png(filename = '" + fileName + "'\n" + 
 			" , width = " + gRO.Width + ", height = " + gRO.Height + ", units = 'px'\n" +
 			" , pointsize = 12, bg = 'white', res = NA)\n";
-		rString += "par(mar=c(" + gRO.MarginBottom + "," + gRO.MarginLeft + "," + gRO.MarginTop + "," + gRO.MarginRight + "))\n";
+		rString += "par(mar=c(" + gRO.MarginBottom + "," + gRO.MarginLeft + "," + gRO.MarginTop + "," + gRO.MarginRight + ")" + cexAxisString + ")\n";
 
 		if(gRO.Type == Constants.GraphTypeBoxplot) {
 			if(hasTwoAxis()) {
