@@ -44,6 +44,20 @@ public class Util
 		myStringBuilder.Replace(",", ".");
 		return myStringBuilder.ToString();
 	}
+
+	//when we do a query to the server, it returns avg as "0,54" because it's latin localized
+	//if client is on english machine, need to convert this to "0.54"
+	public static string ConvertToPointIfNeeded (string myString)
+	{
+		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
+		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
+		
+		StringBuilder myStringBuilder = new StringBuilder(myString);
+		if(localeInfo.NumberDecimalSeparator == ".") {
+			myStringBuilder.Replace(",", localeInfo.NumberDecimalSeparator);
+		}
+		return myStringBuilder.ToString();
+	}
 	
 	
 	//used for load from the database all numbers with correct decimal separator (locale defined)
@@ -292,7 +306,7 @@ public class Util
 	public static string GetHeightInCentimeters (string time) {
 		// s = 4.9 * (tv/2)^2
 		double timeAsDouble = Convert.ToDouble(time);
-		double height = 100 * 4.9 * ( timeAsDouble / 2.0 ) * ( timeAsDouble / 2.0 ) ;
+		double height = 100 * 4.9 * Math.Pow( timeAsDouble / 2.0 , 2 );
 
 		return height.ToString();
 	}
@@ -667,6 +681,115 @@ public class Util
 		return Path.Combine(Path.GetTempPath(), "Chronojump");
 	}
 
+	
+	/********** start of multimedia paths ************/
+
+	public static string GetMultimediaDir() {
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "multimedia");
+	}
+	
+	public static string GetPhotosDir(bool small) {
+		string smallDir = "";
+		if(small)
+			smallDir = Path.DirectorySeparatorChar + Constants.SmallPhotoDir; 
+
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "multimedia" +
+				Path.DirectorySeparatorChar + "photos") + smallDir;
+	}
+	
+	public static string GetVideosDir() {
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "multimedia" +
+				Path.DirectorySeparatorChar + "videos");
+	}
+	
+
+	//to store user videos and photos
+	public static void CreateMultimediaDirsIfNeeded () {
+		string [] dirs = { GetMultimediaDir(), GetPhotosDir(false), GetPhotosDir(true), GetVideosDir() }; 
+		foreach (string d in dirs) {
+			if( ! Directory.Exists(d)) {
+				Directory.CreateDirectory (d);
+				Log.WriteLine (string.Format("created dir: {0}", d));
+			}
+		}
+	}
+	
+	//videos ar organized by sessions. Photos no.	
+	public static string GetVideoSessionDir (int sessionID) {
+		return GetVideosDir() + Path.DirectorySeparatorChar + sessionID.ToString();
+	}
+	
+	public static void CreateVideoSessionDirIfNeeded (int sessionID) {
+		string sessionDir = GetVideoSessionDir(sessionID);
+		if( ! Directory.Exists(sessionDir)) {
+			Directory.CreateDirectory (sessionDir);
+			Log.WriteLine (string.Format("created dir: {0}", sessionDir));
+		}
+	}
+
+	public static string GetVideoFileName (int sessionID, Constants.TestTypes testType, int uniqueID) {
+		return GetVideoSessionDir(sessionID) + Path.DirectorySeparatorChar + 
+			testType.ToString() + "-" + uniqueID.ToString() +
+			GetMultimediaExtension(Constants.MultimediaItems.VIDEO);
+	}
+	
+	public static string GetPhotoFileName (bool small, int uniqueID) {
+		return GetPhotosDir(small) + Path.DirectorySeparatorChar + uniqueID.ToString() +
+			GetMultimediaExtension(Constants.MultimediaItems.PHOTO);
+	}
+	
+	public static string GetVideoTempFileName() {
+		return Path.Combine(
+				Path.GetTempPath(), Constants.VideoTemp + 
+				GetMultimediaExtension(Constants.MultimediaItems.VIDEO));
+	}
+	
+	public static string GetPhotoTempFileName(bool small) {
+		string fileName = Constants.PhotoTemp;
+		if(small)
+			fileName = Constants.PhotoSmallTemp;
+
+		return Path.Combine(
+				Path.GetTempPath(), fileName + GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
+	}
+	
+	
+	
+	public static string GetMultimediaExtension (Constants.MultimediaItems multimediaItem) {
+		if(multimediaItem == Constants.MultimediaItems.VIDEO)
+			return Constants.ExtensionVideo;
+		else //multimediaItem = Constants.MultimediaItems.PHOTO
+			return Constants.ExtensionPhoto;
+	}
+			
+	public static void MoveTempVideo(int sessionID, Constants.TestTypes type, int uniqueID) {
+		if(File.Exists(GetVideoTempFileName())) {
+			CreateVideoSessionDirIfNeeded(sessionID);
+			try {
+				File.Move(GetVideoTempFileName(), GetVideoFileName(sessionID, type, uniqueID));
+			} catch {
+				File.Copy(GetVideoTempFileName(), GetVideoFileName(sessionID, type, uniqueID));
+			}
+		}
+	}
+	
+	public static void DeleteVideo(int sessionID, Constants.TestTypes type, int uniqueID) {
+		string fileName = GetVideoFileName(sessionID, type, uniqueID);
+		if(File.Exists(fileName)) 
+			File.Delete(fileName);
+	}
+
+
+
+	/********** end of multimedia paths ************/
+	
+
 	public static string GetManualDir() {
 		//we are on:
 		//lib/chronojump/ (Unix) or bin/ (win32)
@@ -716,6 +839,7 @@ public class Util
 			Log.WriteLine("Error, chronojump.db file doesn't exist!");
 		}
 	}
+	
 
 	public static void RunRScript(string rScript){
 		ProcessStartInfo pinfo;
@@ -1086,6 +1210,13 @@ public class Util
 			return Constants.No;
 	}
 
+	public static string NoYes(bool b) {
+		if(! b)
+			return Constants.No;
+		else
+			return Constants.Yes;
+	}
+
 
 	/* 
 	 * when distances are variable on run interval 
@@ -1136,5 +1267,42 @@ public class Util
 		}
 		return searchedValue;
 	}
+	
+	public static string GetRunISpeedsString(double distanceInterval, string timesString, 
+			string distancesString, string separator, int maxRuns) 
+	{
+		string [] times = timesString.Split(new char[] {'='});
+		string [] distances = distancesString.Split(new char[] {'-'});
+		string speeds = "";
+		string sep = "";
+		double distance;
+		int i;
+		for(i=0; i < times.Length; i++) {
+			double time = Convert.ToDouble(times[i]);
+
+			//if has variable distance each track
+			if(distanceInterval == -1.0) {
+				int distPos = i % distances.Length;
+				distance = Convert.ToDouble(distances[distPos]);
+			} else 
+				distance = distanceInterval;
+
+			speeds += sep + (distance / time * 1.0).ToString();
+			sep = separator;
+		}
+		//fill the row with 0's equalling largest row
+		for(int j=i; j < maxRuns; j++) {
+			speeds = speeds + ":-";
+		}
+		return speeds;
+	}
+
+	public static double ConvertFeetInchesToCm(int feet, double inches) {
+		return feet * 30.48 + inches * 2.54;
+	}
+	
+	public static double ConvertPoundsToKg(double pounds) {
+		return pounds * 0.45359237;
+	}
 
 }
