@@ -27,6 +27,12 @@ using Gdk;
 //only Gtk related methods (not used bu the server) this is the differnece with Util
 public class UtilGtk
 {
+	public static Gdk.Color WHITE = new Gdk.Color(0xff,0xff,0xff);
+	public static Gdk.Color BLACK = new Gdk.Color(0x00,0x00,0x00);
+	public static Gdk.Color BLUE = new Gdk.Color(0x6c,0x77,0xab);
+	public static Gdk.Color BLUE_CLEAR = new Gdk.Color(0xa0,0xa7,0xca);
+	public static Gdk.Color GREEN = new Gdk.Color(0xa8,0xaf,0xd0);
+	
 	public static void ResizeIfNeeded(Gtk.Window win) {
 		int winX, winY;
 		win.GetSize(out winX, out winY);
@@ -66,7 +72,25 @@ public class UtilGtk
 		return myText;
 	}
 
+	//this is better than the below method, because this search in current combo values
+	//if we use a predefined set of values (like below method), we can have problems 
+	//if some of the values in predefined list have been deleted on combo
+	public static int ComboMakeActive(ComboBox myCombo, string searched) {
+		int returnValue = 0;
+		int count = 0;
+		TreeIter iter;
+		myCombo.Model.GetIterFirst(out iter);
+		do {
+			if( ((string) myCombo.Model.GetValue (iter, 0)) == searched)
+				returnValue = count;
+			count ++;
+		} while (myCombo.Model.IterNext (ref iter));
+
+		return returnValue;
+	}
+
 	//this is not truly gtk related		
+	//better use above method
 	public static int ComboMakeActive(string [] allValues, string searched) {
 		int returnValue = 0;
 		int count = 0;
@@ -79,6 +103,14 @@ public class UtilGtk
 		return returnValue;
 	}
 
+	public static void ComboShowAll(ComboBox myCombo) {
+		TreeIter iter;
+		myCombo.Model.GetIterFirst(out iter);
+		do {
+			Log.WriteLine((string) myCombo.Model.GetValue (iter, 0));
+		} while (myCombo.Model.IterNext (ref iter));
+	}
+
 	private static void comboDelAll(ComboBox myCombo) {
 		//myCombo = ComboBox.NewText(); don't work
 		TreeIter myIter;
@@ -127,10 +159,12 @@ public class UtilGtk
 		myCombo.AppendText (myData);
 	}
 
-	public static void CreateCols (Gtk.TreeView tv, Gtk.TreeStore store, string name, int verticalPos) {
+	public static void CreateCols (Gtk.TreeView tv, Gtk.TreeStore store, 
+			string name, int verticalPos, bool visible) {
 		Gtk.TreeViewColumn myCol = new Gtk.TreeViewColumn (name, new CellRendererText(), "text", verticalPos);
 		myCol.SortColumnId = verticalPos;
 		myCol.SortIndicator = true;
+		myCol.Visible = visible;
 		tv.AppendColumn ( myCol );
 	}
 	
@@ -170,5 +204,33 @@ public class UtilGtk
 		box.ShowAll();
 		combo.Sensitive = true;
 	}
+	
+	public static void ColorsMenuLabel(Gtk.Label l) {
+		l.ModifyFg(StateType.Active, UtilGtk.WHITE);
+		l.ModifyFg(StateType.Normal, UtilGtk.BLACK);
+	}
+	
+	public static void ColorsTestLabel(Gtk.Label l) {
+		l.ModifyFg(StateType.Active, UtilGtk.WHITE);
+	}
+	
+	public static void ColorsRadio(Gtk.RadioButton r) {
+		r.ModifyBg(StateType.Normal, WHITE);
+		r.ModifyBg(StateType.Active, BLUE);
+		r.ModifyBg(StateType.Prelight, BLUE_CLEAR);
+	}
+	
+	public static void ColorsCheck(Gtk.CheckButton c) {
+		c.ModifyBg(StateType.Normal, WHITE);
+		c.ModifyBg(StateType.Active, BLUE);
+		c.ModifyBg(StateType.Prelight, BLUE_CLEAR);
+	}
+
+
+	public static TextBuffer TextViewPrint(string message) {
+		TextBuffer tb = new TextBuffer (new TextTagTable());
+		tb.Text = message;
+		return tb;
+	}
 
 }
